hot_search_url = 'https://api.amemv.com/aweme/v1/hot/search/list/'
hot_video_url = 'https://api.amemv.com/aweme/v1/hotsearch/aweme/billboard/'
hot_energy_url = 'https://api.amemv.com/aweme/v1/hotsearch/positive_energy/billboard/'
hot_music_url  ='https://api.amemv.com/aweme/v1/hotsearch/music/billboard/'