from douyin.structures.hot import *
from douyin.structures.music import Music
from douyin.structures.user import User
from douyin.structures.video import Video
from douyin.structures.address import Address