import collections

HotSearch = collections.namedtuple('HotSearch', ['active_time', 'data'])
HotVideo = collections.namedtuple('HotVideo', ['active_time', 'data'])
HotEnergy = collections.namedtuple('HotVideo', ['active_time', 'data'])
HotMusic = collections.namedtuple('HotMusic', ['active_time', 'data'])